==> haskell-yesod-persistent-1.4.0.3-10-armv7h.pkg.tar.xz: usr/share/haskell/haskell-yesod-persistent/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-persistent
version: 1.4.0.3
id: yesod-persistent-1.4.0.3-e292066aa899804c642be44b1d89205f
key: yesod_BWKxdinYojSJbDDdYK5Cq6
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Some helpers for using Persistent from Yesod.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-persistent>
category: Web, Yesod, Database
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Yesod.Persist Yesod.Persist.Core
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-persistent-1.4.0.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-persistent-1.4.0.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-persistent-1.4.0.3
hs-libraries: HSyesod-persistent-1.4.0.3-BWKxdinYojSJbDDdYK5Cq6
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
    conduit-1.2.6.1-0dc23cc567e1e45fd451d3d7a1cbf2ca
    persistent-2.2.4-6358b6402a63bdc879cbf54a9eb5e6c6
    persistent-template-2.1.5-5a5a189d5669eb41fa0516076c32ca83
    resource-pool-0.2.3.2-43a43754061092f307f80bb6d2ee434f
    resourcet-1.1.7.1-53b70bd9a277fdc9d256cfbf9605d278
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    yesod-core-1.4.19-516d05f0f7a24f16b48a3d78a1b5e378
haddock-interfaces: /usr/share/doc/haskell-yesod-persistent/html/yesod-persistent.haddock
haddock-html: /usr/share/doc/haskell-yesod-persistent/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-persistent-1.4.0.3-17-armv7h.pkg.tar.xz: usr/share/haskell/haskell-yesod-persistent/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-persistent
version: 1.4.0.3
id: yesod-persistent-1.4.0.3-3edc22929bdc95f8a7aaec30b1c13cd6
key: yesod_8WOOnvspvvp8deJb9tS6Tj
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Some helpers for using Persistent from Yesod.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-persistent>
category: Web, Yesod, Database
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Yesod.Persist Yesod.Persist.Core
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-persistent-1.4.0.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-persistent-1.4.0.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-persistent-1.4.0.3
hs-libraries: HSyesod-persistent-1.4.0.3-8WOOnvspvvp8deJb9tS6Tj
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
    conduit-1.2.6.2-e9736ac2851958c9940f374454cdc4fe
    persistent-2.2.4-7bfa93ca2781b33384883da4115f96aa
    persistent-template-2.1.5-843c6c1cb8c608f5d7b0340a1ba98852
    resource-pool-0.2.3.2-43a43754061092f307f80bb6d2ee434f
    resourcet-1.1.7.2-b95e5d14f30eaa21587bc62eeb9aed0c
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    yesod-core-1.4.19-f58e956f86f9387c891d6fa112ae88e5
haddock-interfaces: /usr/share/doc/haskell-yesod-persistent/html/yesod-persistent.haddock
haddock-html: /usr/share/doc/haskell-yesod-persistent/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
